diff --git a/core/modules/field/lib/Drupal/field/Tests/Views/FieldUITest.php b/core/modules/field/lib/Drupal/field/Tests/Views/FieldUITest.php
index 5748227..70a2c4d 100644
--- a/core/modules/field/lib/Drupal/field/Tests/Views/FieldUITest.php
+++ b/core/modules/field/lib/Drupal/field/Tests/Views/FieldUITest.php
@@ -63,7 +63,7 @@ public function setUp() {
* Tests basic field handler settings in the UI.
*/
public function testHandlerUI() {
- $url = "admin/structure/views/nojs/config-item/test_view_fieldapi/default/field/field_name_0";
+ $url = "admin/structure/views/nojs/config-handler/test_view_fieldapi/default/field/field_name_0";
$this->drupalGet($url);
// Tests the available formatter options.
@@ -101,7 +101,7 @@ public function testHandlerUIAggregation() {
$edit = array('group_by' => '1');
$this->drupalPostForm('admin/structure/views/nojs/display/test_view_fieldapi/default/group_by', $edit, t('Apply'));
- $url = "admin/structure/views/nojs/config-item/test_view_fieldapi/default/field/field_name_0";
+ $url = "admin/structure/views/nojs/config-handler/test_view_fieldapi/default/field/field_name_0";
$this->drupalGet($url);
$this->assertResponse(200);
diff --git a/core/modules/taxonomy/lib/Drupal/taxonomy/Tests/Views/TaxonomyIndexTidUiTest.php b/core/modules/taxonomy/lib/Drupal/taxonomy/Tests/Views/TaxonomyIndexTidUiTest.php
index 6b59ca6..5e35457 100644
--- a/core/modules/taxonomy/lib/Drupal/taxonomy/Tests/Views/TaxonomyIndexTidUiTest.php
+++ b/core/modules/taxonomy/lib/Drupal/taxonomy/Tests/Views/TaxonomyIndexTidUiTest.php
@@ -76,7 +76,7 @@ public function testFilterUI() {
}
}
- $this->drupalGet('admin/structure/views/nojs/config-item/test_filter_taxonomy_index_tid/default/filter/tid');
+ $this->drupalGet('admin/structure/views/nojs/config-handler/test_filter_taxonomy_index_tid/default/filter/tid');
$result = $this->xpath('//select[@id="edit-options-value"]/option');
@@ -100,7 +100,7 @@ public function testFilterUI() {
$display =& $view->getDisplay('default');
$display['display_options']['filters']['tid']['type'] = 'textfield';
$view->save();
- $this->drupalGet('admin/structure/views/nojs/config-item/test_filter_taxonomy_index_tid/default/filter/tid');
+ $this->drupalGet('admin/structure/views/nojs/config-handler/test_filter_taxonomy_index_tid/default/filter/tid');
$result = $this->xpath('//input[@id="edit-options-value"]/@data-autocomplete-path');
$this->assertEqual((string) $result[0], url('taxonomy/autocomplete_vid/tags'));
}
diff --git a/core/modules/user/lib/Drupal/user/Tests/Views/HandlerFilterUserNameTest.php b/core/modules/user/lib/Drupal/user/Tests/Views/HandlerFilterUserNameTest.php
index 1f44b70..cfec721 100644
--- a/core/modules/user/lib/Drupal/user/Tests/Views/HandlerFilterUserNameTest.php
+++ b/core/modules/user/lib/Drupal/user/Tests/Views/HandlerFilterUserNameTest.php
@@ -98,7 +98,7 @@ public function testAdminUserInterface() {
$admin_user = $this->drupalCreateUser(array('administer views', 'administer site configuration'));
$this->drupalLogin($admin_user);
- $path = 'admin/structure/views/nojs/config-item/test_user_name/default/filter/uid';
+ $path = 'admin/structure/views/nojs/config-handler/test_user_name/default/filter/uid';
$this->drupalGet($path);
// Pass in an invalid username, the validation should catch it.
diff --git a/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php b/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php
index 78f7934..8eecaed 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php
@@ -67,7 +67,7 @@ public function testUI() {
$types = array('header', 'footer', 'empty');
$labels = array();
foreach ($types as $type) {
- $edit_path = 'admin/structure/views/nojs/config-item/test_example_area/default/' . $type .'/test_example';
+ $edit_path = 'admin/structure/views/nojs/config-handler/test_example_area/default/' . $type .'/test_example';
// First setup an empty label.
$this->drupalPostForm($edit_path, array(), t('Apply'));
@@ -127,7 +127,7 @@ public function testRenderAreaToken() {
$view = views_get_view('test_example_area');
$view->initHandlers();
- $this->drupalGet('admin/structure/views/nojs/config-item/test_example_area/default/empty/test_example');
+ $this->drupalGet('admin/structure/views/nojs/config-handler/test_example_area/default/empty/test_example');
// Test that the list is token present.
$element = $this->xpath('//ul[@class="global-tokens"]');
diff --git a/core/modules/views/lib/Drupal/views/Tests/Handler/FilterDateTest.php b/core/modules/views/lib/Drupal/views/Tests/Handler/FilterDateTest.php
index 782f51d..97b8917 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Handler/FilterDateTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Handler/FilterDateTest.php
@@ -154,7 +154,7 @@ protected function _testUiValidation() {
$this->drupalLogin($this->drupalCreateUser(array('administer views', 'administer site configuration')));
menu_router_rebuild();
$this->drupalGet('admin/structure/views/view/test_filter_date_between/edit');
- $this->drupalGet('admin/structure/views/nojs/config-item/test_filter_date_between/default/filter/created');
+ $this->drupalGet('admin/structure/views/nojs/config-handler/test_filter_date_between/default/filter/created');
$edit = array();
// Generate a definitive wrong value, which should be checked by validation.
diff --git a/core/modules/views/lib/Drupal/views/Tests/Handler/HandlerTest.php b/core/modules/views/lib/Drupal/views/Tests/Handler/HandlerTest.php
index 7c8c6ab..6003536 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Handler/HandlerTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Handler/HandlerTest.php
@@ -78,7 +78,7 @@ function testFilterInOperatorUi() {
$this->drupalLogin($admin_user);
menu_router_rebuild();
- $path = 'admin/structure/views/nojs/config-item/test_filter_in_operator_ui/default/filter/type';
+ $path = 'admin/structure/views/nojs/config-handler/test_filter_in_operator_ui/default/filter/type';
$this->drupalGet($path);
$this->assertFieldByName('options[expose][reduce]', FALSE);
@@ -244,7 +244,7 @@ public function testRelationshipUI() {
$this->drupalLogin($views_admin);
// Make sure the link to the field options exists.
- $handler_options_path = 'admin/structure/views/nojs/config-item/test_handler_relationships/default/field/title';
+ $handler_options_path = 'admin/structure/views/nojs/config-handler/test_handler_relationships/default/field/title';
$view_edit_path = 'admin/structure/views/view/test_handler_relationships/edit';
$this->drupalGet($view_edit_path);
$this->assertLinkByHref($handler_options_path);
@@ -270,7 +270,7 @@ public function testRelationshipUI() {
$this->assertEqual($options, $expected_options);
// Remove the relationship and take sure no relationship option appears.
- $this->drupalPostForm('admin/structure/views/nojs/config-item/test_handler_relationships/default/relationship/nid', array(), t('Remove'));
+ $this->drupalPostForm('admin/structure/views/nojs/config-handler/test_handler_relationships/default/relationship/nid', array(), t('Remove'));
$this->drupalGet($handler_options_path);
$this->assertNoFieldByName($relationship_name, 'Make sure that no relationship option is available');
}
diff --git a/core/modules/views/lib/Drupal/views/Tests/Plugin/ArgumentDefaultTest.php b/core/modules/views/lib/Drupal/views/Tests/Plugin/ArgumentDefaultTest.php
index e1d01c5..23557da 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Plugin/ArgumentDefaultTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Plugin/ArgumentDefaultTest.php
@@ -94,7 +94,7 @@ function testArgumentDefaultNoOptions() {
$edit = array(
'options[default_argument_type]' => $argument_type,
);
- $this->drupalPostForm('admin/structure/views/nojs/config-item/test_argument_default_current_user/default/argument/uid', $edit, t('Apply'));
+ $this->drupalPostForm('admin/structure/views/nojs/config-handler/test_argument_default_current_user/default/argument/uid', $edit, t('Apply'));
// Note, the undefined index error has two spaces after it.
$error = array(
diff --git a/core/modules/views_ui/js/views-admin.js b/core/modules/views_ui/js/views-admin.js
index 7594d17..1147085 100644
--- a/core/modules/views_ui/js/views-admin.js
+++ b/core/modules/views_ui/js/views-admin.js
@@ -770,7 +770,7 @@ $.extend(Drupal.viewsUi.RearrangeFilterHandler.prototype, {
Drupal.behaviors.viewsFilterConfigSelectAll = {
attach: function (context) {
// Show the select all checkbox.
- $(context).find('#views-ui-config-item-form div.form-item-options-value-all').once('filterConfigSelectAll')
+ $(context).find('#views-ui-config-handler-form div.form-item-options-value-all').once('filterConfigSelectAll')
.show()
.find('input[type=checkbox]')
.on('click', function () {
@@ -781,7 +781,7 @@ Drupal.behaviors.viewsFilterConfigSelectAll = {
});
});
// Uncheck the select all checkbox if any of the others are unchecked.
- $('#views-ui-config-item-form').find('div.form-type-checkbox').not($('.form-item-options-value-all'))
+ $('#views-ui-config-handler-form').find('div.form-type-checkbox').not($('.form-item-options-value-all'))
.find('input[type=checkbox]')
.on('click', function () {
if ($(this).is('checked') === false) {
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/Tests/CustomBooleanTest.php b/core/modules/views_ui/lib/Drupal/views_ui/Tests/CustomBooleanTest.php
index ae17b19..5b1c494 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/Tests/CustomBooleanTest.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/Tests/CustomBooleanTest.php
@@ -96,7 +96,7 @@ public function testCustomOption() {
'options[type_custom_true]' => $values['true'],
'options[type_custom_false]' => $values['false'],
);
- $this->drupalPostForm('admin/structure/views/nojs/config-item/test_view/default/field/age', $options, 'Apply');
+ $this->drupalPostForm('admin/structure/views/nojs/config-handler/test_view/default/field/age', $options, 'Apply');
// Save the view.
$this->drupalPostForm('admin/structure/views/view/test_view', array(), 'Save');
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/Tests/ExposedFormUITest.php b/core/modules/views_ui/lib/Drupal/views_ui/Tests/ExposedFormUITest.php
index 0df5845..98e8e45 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/Tests/ExposedFormUITest.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/Tests/ExposedFormUITest.php
@@ -46,7 +46,7 @@ function testExposedAdminUi() {
menu_router_rebuild();
$edit = array();
- $this->drupalGet('admin/structure/views/nojs/config-item/test_exposed_admin_ui/default/filter/type');
+ $this->drupalGet('admin/structure/views/nojs/config-handler/test_exposed_admin_ui/default/filter/type');
// Be sure that the button is called exposed.
$this->helperButtonHasLabel('edit-options-expose-button-button', t('Expose filter'));
@@ -58,7 +58,7 @@ function testExposedAdminUi() {
$this->assertFieldById('edit-options-value-article', '', 'Checkbox for Article exists');
// Click the Expose filter button.
- $this->drupalPostForm('admin/structure/views/nojs/config-item/test_exposed_admin_ui/default/filter/type', $edit, t('Expose filter'));
+ $this->drupalPostForm('admin/structure/views/nojs/config-handler/test_exposed_admin_ui/default/filter/type', $edit, t('Expose filter'));
// Check the label of the expose button.
$this->helperButtonHasLabel('edit-options-expose-button-button', t('Hide filter'));
// Check the label of the grouped exposed button
@@ -82,12 +82,12 @@ function testExposedAdminUi() {
$this->assertText(t('This identifier is not allowed.'));
// Now check the sort criteria.
- $this->drupalGet('admin/structure/views/nojs/config-item/test_exposed_admin_ui/default/sort/created');
+ $this->drupalGet('admin/structure/views/nojs/config-handler/test_exposed_admin_ui/default/sort/created');
$this->helperButtonHasLabel('edit-options-expose-button-button', t('Expose sort'));
$this->assertNoFieldById('edit-options-expose-label', '', 'Make sure no label field is shown');
// Click the Grouped Filters button.
- $this->drupalGet('admin/structure/views/nojs/config-item/test_exposed_admin_ui/default/filter/type');
+ $this->drupalGet('admin/structure/views/nojs/config-handler/test_exposed_admin_ui/default/filter/type');
$this->drupalPostForm(NULL, array(), t('Grouped filters'));
// After click on 'Grouped Filters', the standard operator and value should
@@ -102,7 +102,7 @@ function testExposedAdminUi() {
$this->helperButtonHasLabel('edit-options-group-info-add-group', t('Add another item'));
// Create a grouped filter
- $this->drupalGet('admin/structure/views/nojs/config-item/test_exposed_admin_ui/default/filter/type');
+ $this->drupalGet('admin/structure/views/nojs/config-handler/test_exposed_admin_ui/default/filter/type');
$edit = array();
$edit["options[group_info][group_items][1][title]"] = 'Is Article';
$edit["options[group_info][group_items][1][value][article]"] = 'article';
@@ -117,7 +117,7 @@ function testExposedAdminUi() {
// Select the empty operator, so the empty value should not trigger a form
// error.
- $this->drupalGet('admin/structure/views/nojs/config-item/test_exposed_admin_ui/default/filter/body_value');
+ $this->drupalGet('admin/structure/views/nojs/config-handler/test_exposed_admin_ui/default/filter/body_value');
$edit = array();
$edit["options[group_info][group_items][1][title]"] = $this->randomName();
$edit["options[group_info][group_items][1][operator]"] = 'empty';
@@ -127,7 +127,7 @@ function testExposedAdminUi() {
$this->assertNoText(t('The value is required if title for this item is defined.'));
// Validate that all the titles are defined for each group
- $this->drupalGet('admin/structure/views/nojs/config-item/test_exposed_admin_ui/default/filter/type');
+ $this->drupalGet('admin/structure/views/nojs/config-handler/test_exposed_admin_ui/default/filter/type');
$edit = array();
$edit["options[group_info][group_items][1][title]"] = 'Is Article';
$edit["options[group_info][group_items][1][value][article]"] = TRUE;
@@ -143,7 +143,7 @@ function testExposedAdminUi() {
$this->assertRaw(t('The title is required if value for this item is defined.'), 'Group items should have a title');
// Un-expose the filter.
- $this->drupalGet('admin/structure/views/nojs/config-item/test_exposed_admin_ui/default/filter/type');
+ $this->drupalGet('admin/structure/views/nojs/config-handler/test_exposed_admin_ui/default/filter/type');
$this->drupalPostForm(NULL, array(), t('Hide filter'));
// After Un-exposing the filter, Operator and Value should be shown again.
@@ -154,7 +154,7 @@ function testExposedAdminUi() {
// Click the Expose sort button.
$edit = array();
- $this->drupalPostForm('admin/structure/views/nojs/config-item/test_exposed_admin_ui/default/sort/created', $edit, t('Expose sort'));
+ $this->drupalPostForm('admin/structure/views/nojs/config-handler/test_exposed_admin_ui/default/sort/created', $edit, t('Expose sort'));
// Check the label of the expose button.
$this->helperButtonHasLabel('edit-options-expose-button-button', t('Hide sort'));
$this->assertFieldById('edit-options-expose-label', '', 'Make sure a label field is shown');
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/Tests/FieldUITest.php b/core/modules/views_ui/lib/Drupal/views_ui/Tests/FieldUITest.php
index 725ccd9..6ce0cfa 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/Tests/FieldUITest.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/Tests/FieldUITest.php
@@ -39,7 +39,7 @@ public function testFieldUI() {
$this->assertNoText('Views test: Name (Name) [' . t('hidden') . ']');
// Hides the field and check whether the hidden label is appended.
- $edit_handler_url = 'admin/structure/views/nojs/config-item/test_view/default/field/name';
+ $edit_handler_url = 'admin/structure/views/nojs/config-handler/test_view/default/field/name';
$this->drupalPostForm($edit_handler_url, array('options[exclude]' => TRUE), t('Apply'));
$this->assertText('Views test: Name (Name) [' . t('hidden') . ']');
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/Tests/FilterBooleanWebTest.php b/core/modules/views_ui/lib/Drupal/views_ui/Tests/FilterBooleanWebTest.php
index 59c2161..9d21ecb 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/Tests/FilterBooleanWebTest.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/Tests/FilterBooleanWebTest.php
@@ -51,7 +51,7 @@ public function testFilterBooleanUI() {
$this->drupalPostForm(NULL, $edit, t('Apply'));
- $this->drupalGet('admin/structure/views/nojs/config-item/test_view/default/filter/status');
+ $this->drupalGet('admin/structure/views/nojs/config-handler/test_view/default/filter/status');
$result = $this->xpath('//input[@name="options[group_info][group_items][1][value]"]');
$this->assertEqual((int) $result[1]->attributes()->checked, 'checked');
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/Tests/GroupByTest.php b/core/modules/views_ui/lib/Drupal/views_ui/Tests/GroupByTest.php
index cffcfc3..b834405 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/Tests/GroupByTest.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/Tests/GroupByTest.php
@@ -35,7 +35,7 @@ public static function getInfo() {
function testGroupBySave() {
$this->drupalGet('admin/structure/views/view/test_views_groupby_save/edit');
- $edit_groubpy_url = 'admin/structure/views/nojs/config-item-group/test_views_groupby_save/default/field/id';
+ $edit_groubpy_url = 'admin/structure/views/nojs/config-handler-group/test_views_groupby_save/default/field/id';
$this->assertNoLinkByHref($edit_groubpy_url, 0, 'No aggregation link found.');
// Enable aggregation on the view.
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/Tests/HandlerTest.php b/core/modules/views_ui/lib/Drupal/views_ui/Tests/HandlerTest.php
index c7c9baf..6d64ada 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/Tests/HandlerTest.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/Tests/HandlerTest.php
@@ -84,17 +84,17 @@ public function testUICRUD() {
if (in_array($type, array('header', 'footer', 'empty'))) {
$this->drupalPostForm($add_handler_url, array('name[views.area]' => TRUE), t('Add and configure @handler', array('@handler' => $type_info['ltitle'])));
$id = 'area';
- $edit_handler_url = "admin/structure/views/nojs/config-item/test_view_empty/default/$type/$id";
+ $edit_handler_url = "admin/structure/views/nojs/config-handler/test_view_empty/default/$type/$id";
}
elseif ($type == 'relationship') {
$this->drupalPostForm($add_handler_url, array('name[views_test_data.uid]' => TRUE), t('Add and configure @handler', array('@handler' => $type_info['ltitle'])));
$id = 'uid';
- $edit_handler_url = "admin/structure/views/nojs/config-item/test_view_empty/default/$type/$id";
+ $edit_handler_url = "admin/structure/views/nojs/config-handler/test_view_empty/default/$type/$id";
}
else {
$this->drupalPostForm($add_handler_url, array('name[views_test_data.job]' => TRUE), t('Add and configure @handler', array('@handler' => $type_info['ltitle'])));
$id = 'job';
- $edit_handler_url = "admin/structure/views/nojs/config-item/test_view_empty/default/$type/$id";
+ $edit_handler_url = "admin/structure/views/nojs/config-handler/test_view_empty/default/$type/$id";
}
$this->assertUrl($edit_handler_url, array(), 'The user got redirected to the handler edit form.');
@@ -132,7 +132,7 @@ public function testUICRUD() {
$type_info = $handler_types['field'];
$this->drupalPostForm($add_handler_url, array('name[users.signature]' => TRUE), t('Add and configure @handler', array('@handler' => $type_info['ltitle'])));
$id = 'signature';
- $edit_handler_url = "admin/structure/views/nojs/config-item/test_view_empty/default/field/$id";
+ $edit_handler_url = "admin/structure/views/nojs/config-handler/test_view_empty/default/field/$id";
$this->assertUrl($edit_handler_url, array(), 'The user got redirected to the handler edit form.');
$this->assertFieldByName('options[relationship]', 'uid', 'Ensure the relationship select is filled with the UID relationship.');
@@ -152,7 +152,7 @@ public function testBrokenHandlers() {
foreach ($handler_types as $type => $type_info) {
$this->drupalGet('admin/structure/views/view/test_view_broken/edit');
- $href = "admin/structure/views/nojs/config-item/test_view_broken/default/$type/id_broken";
+ $href = "admin/structure/views/nojs/config-handler/test_view_broken/default/$type/id_broken";
$result = $this->xpath('//a[contains(@href, :href)]', array(':href' => $href));
$this->assertEqual(count($result), 1, String::format('Handler (%type) edit link found.', array('%type' => $type)));
@@ -186,7 +186,7 @@ public function testOptionalHandlers() {
foreach ($handler_types as $type => $type_info) {
$this->drupalGet('admin/structure/views/view/test_view_optional/edit');
- $href = "admin/structure/views/nojs/config-item/test_view_optional/default/$type/id_optional";
+ $href = "admin/structure/views/nojs/config-handler/test_view_optional/default/$type/id_optional";
$result = $this->xpath('//a[contains(@href, :href)]', array(':href' => $href));
$this->assertEqual(count($result), 1, String::format('Handler (%type) edit link found.', array('%type' => $type)));
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/ViewEditFormController.php b/core/modules/views_ui/lib/Drupal/views_ui/ViewEditFormController.php
index a16031c..66fb63c 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/ViewEditFormController.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/ViewEditFormController.php
@@ -1037,7 +1037,7 @@ public function getFormBucket(ViewUI $view, $type, $display) {
if ($handler->broken()) {
$build['fields'][$id]['#class'][] = 'broken';
$field_name = $handler->adminLabel();
- $build['fields'][$id]['#link'] = l($field_name, "admin/structure/views/nojs/config-item/{$view->id()}/{$display['id']}/$type/$id", array('attributes' => array('class' => array('views-ajax-link')), 'html' => TRUE));
+ $build['fields'][$id]['#link'] = l($field_name, "admin/structure/views/nojs/config-handler/{$view->id()}/{$display['id']}/$type/$id", array('attributes' => array('class' => array('views-ajax-link')), 'html' => TRUE));
continue;
}
@@ -1054,15 +1054,15 @@ public function getFormBucket(ViewUI $view, $type, $display) {
// Add a [hidden] marker, if the field is excluded.
$link_text .= ' [' . $this->t('hidden') . ']';
}
- $build['fields'][$id]['#link'] = l($link_text, "admin/structure/views/nojs/config-item/{$view->id()}/{$display['id']}/$type/$id", array('attributes' => $link_attributes, 'html' => TRUE));
+ $build['fields'][$id]['#link'] = l($link_text, "admin/structure/views/nojs/config-handler/{$view->id()}/{$display['id']}/$type/$id", array('attributes' => $link_attributes, 'html' => TRUE));
$build['fields'][$id]['#class'][] = drupal_clean_css_identifier($display['id']. '-' . $type . '-' . $id);
if ($executable->display_handler->useGroupBy() && $handler->usesGroupBy()) {
- $build['fields'][$id]['#settings_links'][] = l('' . $this->t('Aggregation settings') . '', "admin/structure/views/nojs/config-item-group/{$view->id()}/{$display['id']}/$type/$id", array('attributes' => array('class' => 'views-button-configure views-ajax-link', 'title' => $this->t('Aggregation settings')), 'html' => TRUE));
+ $build['fields'][$id]['#settings_links'][] = l('' . $this->t('Aggregation settings') . '', "admin/structure/views/nojs/config-handler-group/{$view->id()}/{$display['id']}/$type/$id", array('attributes' => array('class' => 'views-button-configure views-ajax-link', 'title' => $this->t('Aggregation settings')), 'html' => TRUE));
}
if ($handler->hasExtraOptions()) {
- $build['fields'][$id]['#settings_links'][] = l('' . $this->t('Settings') . '', "admin/structure/views/nojs/config-item-extra/{$view->id()}/{$display['id']}/$type/$id", array('attributes' => array('class' => array('views-button-configure', 'views-ajax-link'), 'title' => $this->t('Settings')), 'html' => TRUE));
+ $build['fields'][$id]['#settings_links'][] = l('' . $this->t('Settings') . '', "admin/structure/views/nojs/config-handler-extra/{$view->id()}/{$display['id']}/$type/$id", array('attributes' => array('class' => array('views-button-configure', 'views-ajax-link'), 'title' => $this->t('Settings')), 'html' => TRUE));
}
if ($grouping) {
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/ViewUI.php b/core/modules/views_ui/lib/Drupal/views_ui/ViewUI.php
index 210b0b5..b1fd96c 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/ViewUI.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/ViewUI.php
@@ -128,9 +128,9 @@ class ViewUI implements ViewStorageInterface {
public static $forms = array(
'add-handler' => '\Drupal\views_ui\Form\Ajax\AddItem',
'analyze' => '\Drupal\views_ui\Form\Ajax\Analyze',
- 'config-item' => '\Drupal\views_ui\Form\Ajax\ConfigItem',
- 'config-item-extra' => '\Drupal\views_ui\Form\Ajax\ConfigItemExtra',
- 'config-item-group' => '\Drupal\views_ui\Form\Ajax\ConfigItemGroup',
+ 'config-handler' => '\Drupal\views_ui\Form\Ajax\ConfigHandler',
+ 'config-handler-extra' => '\Drupal\views_ui\Form\Ajax\ConfigHandlerExtra',
+ 'config-handler-group' => '\Drupal\views_ui\Form\Ajax\ConfigHandlerGroup',
'display' => '\Drupal\views_ui\Form\Ajax\Display',
'edit-details' => '\Drupal\views_ui\Form\Ajax\EditDetails',
'rearrange' => '\Drupal\views_ui\Form\Ajax\Rearrange',
@@ -504,15 +504,15 @@ public function submitItemAdd($form, &$form_state) {
);
$handler = Views::handlerManager($key)->getHandler($item);
if ($this->executable->displayHandlers->get('default')->useGroupBy() && $handler->usesGroupBy()) {
- $this->addFormToStack('config-item-group', $form_state['display_id'], $type, $id);
+ $this->addFormToStack('config-handler-group', $form_state['display_id'], $type, $id);
}
// check to see if this type has settings, if so add the settings form first
if ($handler && $handler->hasExtraOptions()) {
- $this->addFormToStack('config-item-extra', $form_state['display_id'], $type, $id);
+ $this->addFormToStack('config-handler-extra', $form_state['display_id'], $type, $id);
}
// Then add the form to the stack
- $this->addFormToStack('config-item', $form_state['display_id'], $type, $id);
+ $this->addFormToStack('config-handler', $form_state['display_id'], $type, $id);
}
}
diff --git a/core/modules/views_ui/views_ui.module b/core/modules/views_ui/views_ui.module
index af9fc88..69b9582 100644
--- a/core/modules/views_ui/views_ui.module
+++ b/core/modules/views_ui/views_ui.module
@@ -215,7 +215,7 @@ function views_ui_view_preview_section_handler_links(ViewExecutable $view, $type
$field_name = $handler->adminLabel(TRUE);
$links[$type . '-edit-' . $id] = array(
'title' => t('Edit @section', array('@section' => $field_name)),
- 'href' => "admin/structure/views/nojs/config-item/{$view->storage->id()}/{$display['id']}/$type/$id",
+ 'href' => "admin/structure/views/nojs/config-handler/{$view->storage->id()}/{$display['id']}/$type/$id",
'attributes' => array('class' => array('views-ajax-link')),
);
}
diff --git a/core/modules/views_ui/views_ui.routing.yml b/core/modules/views_ui/views_ui.routing.yml
index f0235e6..19f3a45 100644
--- a/core/modules/views_ui/views_ui.routing.yml
+++ b/core/modules/views_ui/views_ui.routing.yml
@@ -118,7 +118,7 @@ views_ui.form_add_handler:
view:
tempstore: TRUE
defaults:
- _controller: '\Drupal\views_ui\Form\Ajax\AddItem::getForm'
+ _controller: '\Drupal\views_ui\Form\Ajax\AddHandler::getForm'
requirements:
_permission: 'administer views'
js: 'nojs|ajax'
@@ -195,38 +195,38 @@ views_ui.form_display:
_permission: 'administer views'
js: 'nojs|ajax'
-views_ui.form_config_item:
- path: '/admin/structure/views/{js}/config-item/{view}/{display_id}/{type}/{id}'
+views_ui.form_config_handler:
+ path: '/admin/structure/views/{js}/config-handler/{view}/{display_id}/{type}/{id}'
options:
parameters:
view:
tempstore: TRUE
defaults:
- _controller: '\Drupal\views_ui\Form\Ajax\ConfigItem::getForm'
+ _controller: '\Drupal\views_ui\Form\Ajax\ConfigHandler::getForm'
requirements:
_permission: 'administer views'
js: 'nojs|ajax'
-views_ui.form_config_item_extra:
- path: '/admin/structure/views/{js}/config-item-extra/{view}/{display_id}/{type}/{id}'
+views_ui.form_config_handler_extra:
+ path: '/admin/structure/views/{js}/config-handler-extra/{view}/{display_id}/{type}/{id}'
options:
parameters:
view:
tempstore: TRUE
defaults:
- _controller: '\Drupal\views_ui\Form\Ajax\ConfigItemExtra::getForm'
+ _controller: '\Drupal\views_ui\Form\Ajax\ConfigHandlerExtra::getForm'
requirements:
_permission: 'administer views'
js: 'nojs|ajax'
-views_ui.form_config_item_group:
- path: '/admin/structure/views/{js}/config-item-group/{view}/{display_id}/{type}/{id}'
+views_ui.form_config_handler_group:
+ path: '/admin/structure/views/{js}/config-handler-group/{view}/{display_id}/{type}/{id}'
options:
parameters:
view:
tempstore: TRUE
defaults:
- _controller: '\Drupal\views_ui\Form\Ajax\ConfigItemGroup::getForm'
+ _controller: '\Drupal\views_ui\Form\Ajax\ConfigHandlerGroup::getForm'
form_state: NULL
requirements:
_permission: 'administer views'
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/Form/Ajax/ConfigHandlerGroup.php b/core/modules/views_ui/lib/Drupal/views_ui/Form/Ajax/ConfigHandlerGroup.php
index 1d958cf..8859b73 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/Form/Ajax/ConfigHandlerGroup.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/Form/Ajax/ConfigHandlerGroup.php
@@ -12,7 +12,7 @@
use Drupal\views\ViewExecutable;
/**
* Provides a form for configuring grouping information for a Views UI item.
*/
class ConfigHandlerGroup extends ViewsFormBase {
@@ -28,7 +28,7 @@ public function __construct($type = NULL, $id = NULL) {
* {@inheritdoc}
*/
public function getFormKey() {
- return 'config-item-group';
+ return 'config-handler-group';
}
/**
@@ -12,7 +12,7 @@
use Drupal\views\ViewExecutable;
/**
- * Provides a form for configuring grouping information for a Views UI item.
+ * Provides a form for configuring grouping information for a Views UI handler.
*/
class ConfigHandlerGroup extends ViewsFormBase {